package fr.safepic.jbtm1249;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.sql.Statement;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.annotation.Resource;
import javax.ejb.EJBException;
import javax.ejb.Remote;
import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.sql.DataSource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

@Stateless
@TransactionAttribute(TransactionAttributeType.REQUIRES_NEW)
@Remote(TestEJBRemote.class)
public class TestEJB implements TestEJBRemote {
	private final static Log LOGGER = LogFactory.getLog(TestEJB.class);

	@Resource(name="java:/jdbc/ds1")
	private DataSource ds1;
	
	@Resource(name="java:/jdbc/ds2")
	private DataSource ds2;
    
	public void twoPhaseTest() {
		Connection conDS1 = null;
		Connection conDS2 = null;
		try {
			SimpleDateFormat sdf = new SimpleDateFormat("MM-dd-yyyy HH:mm:ss");
			String stringDate = sdf.format(new Date());
			conDS1 = ds1.getConnection();
			conDS2 = ds2.getConnection();
			insert(conDS1, "tbl1", stringDate);
			insert(conDS2, "tbl2", stringDate);
			LOGGER.info("Insert done");
		} catch (SQLException ne) {
			LOGGER.error("An error occured during twoPhaseTest", ne);
			throw new EJBException("An error occured during twoPhaseTest", ne);
		} finally {
			close(conDS1);
			close(conDS2);
		}
	}
	
	private void insert(Connection con, String tableName, String date) throws SQLException {
		PreparedStatement st1 = null;
		try {
			st1 = con.prepareStatement("INSERT INTO " + tableName + " VALUES (?)");
			st1.setString(1, date);
			if (st1.executeUpdate() != 1) {
				throw new SQLException("Impossible to insert " + date + " into " + tableName);
			}
		} finally {
			close(st1);
		}
	}
	
	private void close(Statement st) {
		if (st != null) {
			try {
				st.close();
			} catch (SQLException ex) {
				LOGGER.error("Impossible to close statement" + ex.getMessage());
			}
		}
	}

	private void close(Connection con) {
		if (con != null) {
			try {
				con.close();
			} catch (SQLException ex) {
				LOGGER.error("Impossible to close connexion" + ex.getMessage());
			}
		}
	}

}
